@@ -1,7 +1,7 @@
 import json
 import os
 
-from deteefapi.dtf_api import DTF_API
+from deteefapi.dtf import DeteefAPI
 
 _CUR_DIR = os.path.dirname(os.path.realpath(__file__))
 DATA_DIR = os.path.join(_CUR_DIR, 'data')
@@ -15,10 +15,10 @@ TEST_SUBSITE_ID = 130721
 
 
 def get_bot():
-    return DTF_API(DTF_CONFIG['token'])
+    return DeteefAPI(DTF_CONFIG['token'])
 
 
-class DTF_API_FAKE(DTF_API):
+class DTF_API_FAKE(DeteefAPI):
     def get(self, *args, **kwargs):
         pass
 
